@@ -638,8 +638,10 @@ enum : int {
     SBK_QTCORE_QHASH_INT_QBYTEARRAY_IDX                      = 39, // QHash<int,QByteArray >
     SBK_QTCORE_QLIST_QABSTRACTITEMMODELPTR_IDX               = 40, // QList<QAbstractItemModel* >
     SBK_QTCORE_QLIST_QABSTRACTEVENTDISPATCHER_TIMERINFO_IDX  = 41, // QList<QAbstractEventDispatcher::TimerInfo >
-    SBK_QTCORE_QLIST_QSTRING_IDX                             = 42, // QList<QString >
-    SBK_QtCore_CONVERTERS_IDX_COUNT                          = 43
+    SBK_QTCORE_STD_PAIR_QREAL_QVARIANT_IDX                   = 42, // std::pair<qreal,QVariant >
+    SBK_QTCORE_QLIST_STD_PAIR_QREAL_QVARIANT_IDX             = 43, // QList<std::pair< qreal,QVariant > >
+    SBK_QTCORE_QLIST_QSTRING_IDX                             = 44, // QList<QString >
+    SBK_QtCore_CONVERTERS_IDX_COUNT                          = 45
 };
 
 // typedef entries
