@@ -541,36 +541,38 @@ enum : int {
     SBK_QTGUI_QLIST_QPOLYGONF_IDX                            = 12, // QList<QPolygonF >
     SBK_QTGUI_QLIST_FLOAT_IDX                                = 13, // QList<float >
     SBK_QTGUI_QLIST_QSIZE_IDX                                = 14, // QList<QSize >
-    SBK_QTGUI_QLIST_INT_IDX                                  = 15, // QList<int >
-    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 16, // QList<QAccessibleInterface* >
-    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 17, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
-    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 18, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
-    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 19, // QList<unsigned int >
-    SBK_QTGUI_QLIST_QLINE_IDX                                = 20, // const QList<QLine > &
-    SBK_QTGUI_QLIST_QLINEF_IDX                               = 21, // const QList<QLineF > &
-    SBK_QTGUI_QLIST_QRECT_IDX                                = 22, // const QList<QRect > &
-    SBK_QTGUI_QLIST_QRECTF_IDX                               = 23, // const QList<QRectF > &
-    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 24, // QList<QKeySequence >
-    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 25, // const QList<QObject* > &
-    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 26, // QList<QByteArray >
-    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 27, // QList<QUndoStack* >
-    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 28, // QList<QTextFrame* >
-    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 29, // QList<QTextBlock >
-    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 30, // QList<QTextFormat >
-    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 31, // QList<QScreen* >
-    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 32, // QList<QOpenGLContext* >
-    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 33, // QSet<QByteArray >
-    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 34, // QList<const QInputDevice* >
-    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 35, // QList<QAction* >
-    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 36, // const QList<QInputMethodEvent::Attribute > &
-    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 37, // const QList<QEventPoint > &
-    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 38, // QList<QWindow* >
-    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 39, // const QList<QPersistentModelIndex > &
-    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 40, // QHash<int,QByteArray >
-    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 41, // QList<QVariant >
-    SBK_QTGUI_QLIST_QSTRING_IDX                              = 42, // QList<QString >
-    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 43, // QMap<QString,QVariant >
-    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 44
+    SBK_QTGUI_STD_PAIR_QREAL_QCOLOR_IDX                      = 15, // std::pair<qreal,QColor >
+    SBK_QTGUI_QLIST_STD_PAIR_QREAL_QCOLOR_IDX                = 16, // const QList<std::pair< qreal,QColor > > &
+    SBK_QTGUI_QLIST_INT_IDX                                  = 17, // QList<int >
+    SBK_QTGUI_QLIST_QACCESSIBLEINTERFACEPTR_IDX              = 18, // QList<QAccessibleInterface* >
+    SBK_QTGUI_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 19, // QPair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag> >
+    SBK_QTGUI_QLIST_QPAIR_QACCESSIBLEINTERFACEPTR_QFLAGS_QACCESSIBLE_RELATIONFLAG_IDX = 20, // QList<QPair< QAccessibleInterface*,QFlags<QAccessible::RelationFlag> > >
+    SBK_QTGUI_QLIST_UNSIGNEDINT_IDX                          = 21, // QList<unsigned int >
+    SBK_QTGUI_QLIST_QLINE_IDX                                = 22, // const QList<QLine > &
+    SBK_QTGUI_QLIST_QLINEF_IDX                               = 23, // const QList<QLineF > &
+    SBK_QTGUI_QLIST_QRECT_IDX                                = 24, // const QList<QRect > &
+    SBK_QTGUI_QLIST_QRECTF_IDX                               = 25, // const QList<QRectF > &
+    SBK_QTGUI_QLIST_QKEYSEQUENCE_IDX                         = 26, // QList<QKeySequence >
+    SBK_QTGUI_QLIST_QOBJECTPTR_IDX                           = 27, // const QList<QObject* > &
+    SBK_QTGUI_QLIST_QBYTEARRAY_IDX                           = 28, // QList<QByteArray >
+    SBK_QTGUI_QLIST_QUNDOSTACKPTR_IDX                        = 29, // QList<QUndoStack* >
+    SBK_QTGUI_QLIST_QTEXTFRAMEPTR_IDX                        = 30, // QList<QTextFrame* >
+    SBK_QTGUI_QLIST_QTEXTBLOCK_IDX                           = 31, // QList<QTextBlock >
+    SBK_QTGUI_QLIST_QTEXTFORMAT_IDX                          = 32, // QList<QTextFormat >
+    SBK_QTGUI_QLIST_QSCREENPTR_IDX                           = 33, // QList<QScreen* >
+    SBK_QTGUI_QLIST_QOPENGLCONTEXTPTR_IDX                    = 34, // QList<QOpenGLContext* >
+    SBK_QTGUI_QSET_QBYTEARRAY_IDX                            = 35, // QSet<QByteArray >
+    SBK_QTGUI_QLIST_CONSTQINPUTDEVICEPTR_IDX                 = 36, // QList<const QInputDevice* >
+    SBK_QTGUI_QLIST_QACTIONPTR_IDX                           = 37, // QList<QAction* >
+    SBK_QTGUI_QLIST_QINPUTMETHODEVENT_ATTRIBUTE_IDX          = 38, // const QList<QInputMethodEvent::Attribute > &
+    SBK_QTGUI_QLIST_QEVENTPOINT_IDX                          = 39, // const QList<QEventPoint > &
+    SBK_QTGUI_QLIST_QWINDOWPTR_IDX                           = 40, // QList<QWindow* >
+    SBK_QTGUI_QLIST_QPERSISTENTMODELINDEX_IDX                = 41, // const QList<QPersistentModelIndex > &
+    SBK_QTGUI_QHASH_INT_QBYTEARRAY_IDX                       = 42, // QHash<int,QByteArray >
+    SBK_QTGUI_QLIST_QVARIANT_IDX                             = 43, // QList<QVariant >
+    SBK_QTGUI_QLIST_QSTRING_IDX                              = 44, // QList<QString >
+    SBK_QTGUI_QMAP_QSTRING_QVARIANT_IDX                      = 45, // QMap<QString,QVariant >
+    SBK_QtGui_CONVERTERS_IDX_COUNT                           = 46
 };
 // Macros for type check
 
