@@ -232,24 +232,26 @@ enum : int {
     SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 6, // QList<QHostAddress >
     SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 7, // QList<QNetworkInterface >
     SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 8, // QHash<QNetworkRequest::Attribute,QVariant >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 9, // const QPair<QHostAddress,int > &
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 10, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 11, // const QList<QObject* > &
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 12, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 13, // const QList<QHstsPolicy > &
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 14, // const QList<QSslError > &
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 15, // QList<QDnsDomainNameRecord >
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 16, // QList<QDnsHostAddressRecord >
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 17, // QList<QDnsMailExchangeRecord >
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 18, // QList<QDnsServiceRecord >
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 19, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 20, // QList<QOcspResponse >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 21, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 22, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 23, // QList<QVariant >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 24, // QList<QString >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 25, // QMap<QString,QVariant >
-    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 26
+    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 9, // std::pair<QByteArray,QByteArray >
+    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 10, // QList<std::pair< QByteArray,QByteArray > >
+    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 11, // const QPair<QHostAddress,int > &
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 12, // QHash<QString,QVariant >
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 13, // const QList<QObject* > &
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 14, // QList<QNetworkCookie >
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 15, // const QList<QHstsPolicy > &
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 16, // const QList<QSslError > &
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 17, // QList<QDnsDomainNameRecord >
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 18, // QList<QDnsHostAddressRecord >
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 19, // QList<QDnsMailExchangeRecord >
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 20, // QList<QDnsServiceRecord >
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 21, // QList<QDnsTextRecord >
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 22, // QList<QOcspResponse >
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 23, // QList<QSslCertificateExtension >
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 24, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 25, // QList<QVariant >
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 26, // QList<QString >
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 27, // QMap<QString,QVariant >
+    SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 28
 };
 // Macros for type check
 
